from enum import Enum


class Task(str, Enum):
    RUN_SERVICE = "RUN_SERVICE"
    LIST_SERVICES = "LIST_SERVICES"
    GET_SERVICE_DETAILS = "GET_SERVICE_DETAILS"


class ServerTask(str, Enum):
    UPDATE_AGENT_STATUS = "UPDATE_AGENT_STATUS"
    UPDATE_SERVICE_STATUS = "UPDATE_SERVICE_STATUS"
    UPDATE_SERVICE_OUTPUTS = "UPDATE_SERVICE_OUTPUTS"
